@@ -628,7 +628,8 @@ class TestElasticSearchEngine_backup(unittest.TestCase):
     def setUp(self, mock_logging, mock_elasticsearch):
         mock_elasticsearch.Elasticsearch.return_value = mock.Mock()
         kwargs = {'hosts': 'http://elasticservaddr:1997'}
-        self.eng = elastic.ElasticSearchEngine(index='freezer', **kwargs)
+        self.eng = elastic.ElasticSearchEngine(backend='elasticsearch')
+        self.eng.init(index='freezer', **kwargs)
         self.eng.backup_manager = mock.Mock()
 
     def test_get_backup_userid_and_backup_id_return_ok(self):
@@ -730,7 +731,8 @@ class TestElasticSearchEngine_client(unittest.TestCase):
     def setUp(self, mock_logging, mock_elasticsearch):
         mock_elasticsearch.Elasticsearch.return_value = mock.Mock()
         kwargs = {'hosts': 'http://elasticservaddr:1997'}
-        self.eng = elastic.ElasticSearchEngine(index='freezer', **kwargs)
+        self.eng = elastic.ElasticSearchEngine(backend="elasticsearch")
+        self.eng.init(index='freezer', **kwargs)
         self.eng.client_manager = mock.Mock()
 
     def test_get_client_userid_and_client_id_return_1elem_list_(self):
@@ -839,7 +841,8 @@ class TestElasticSearchEngine_job(unittest.TestCase):
     def setUp(self, mock_elasticsearch, mock_logging):
         mock_elasticsearch.Elasticsearch.return_value = mock.Mock()
         kwargs = {'hosts': 'http://elasticservaddr:1997'}
-        self.eng = elastic.ElasticSearchEngine(index='freezer', **kwargs)
+        self.eng = elastic.ElasticSearchEngine(backend="elasticsearch")
+        self.eng.init(index='freezer', **kwargs)
         self.eng.job_manager = mock.Mock()
 
     def test_get_job_userid_and_job_id_return_doc(self):
@@ -986,7 +989,8 @@ class TestElasticSearchEngine_action(unittest.TestCase):
     def setUp(self, mock_elasticsearch, mock_logging):
         mock_elasticsearch.Elasticsearch.return_value = mock.Mock()
         kwargs = {'hosts': 'http://elasticservaddr:1997'}
-        self.eng = elastic.ElasticSearchEngine(index='freezer', **kwargs)
+        self.eng = elastic.ElasticSearchEngine(backend="elasticsearch")
+        self.eng.init(index='freezer', **kwargs)
         self.eng.action_manager = mock.Mock()
 
     def test_get_action_userid_and_action_id_return_doc(self):
@@ -1142,7 +1146,8 @@ class TestElasticSearchEngine_session(unittest.TestCase):
     def setUp(self, mock_elasticsearch, mock_logging):
         mock_elasticsearch.Elasticsearch.return_value = mock.Mock()
         kwargs = {'hosts': 'http://elasticservaddr:1997'}
-        self.eng = elastic.ElasticSearchEngine(index='freezer', **kwargs)
+        self.eng = elastic.ElasticSearchEngine(backend="elasticsearch")
+        self.eng.init(index='freezer', **kwargs)
         self.eng.session_manager = mock.Mock()
 
     def test_get_session_userid_and_session_id_return_doc(self):
